@@ -103,6 +103,18 @@ describe 'tempest' do
       end
     end
 
+    context 'with sahara_plugins' do
+      let :params do
+        { :configure_images => false,
+          :sahara_available => true,
+          :sahara_plugins   => ['vanilla'] }
+      end
+
+      it 'properly configures Sahara plugins in tempest.conf' do
+        is_expected.to contain_tempest_config('data-processing-feature-enabled/plugins').with_value(['vanilla'])
+      end
+    end
+
     context 'with parameters' do
       let :params do
         { :configure_images    => true,
@@ -158,6 +170,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('compute/image_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('compute/resize_available').with(:value => nil)
           is_expected.to contain_tempest_config('compute/allow_tenant_isolation').with(:value => nil)
+          is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
           is_expected.to contain_tempest_config('identity/admin_password').with(:value => nil)
           is_expected.to contain_tempest_config('identity/admin_domain_name').with(:value => nil)
           is_expected.to contain_tempest_config('identity/admin_password').with_secret( true )
@@ -175,6 +188,8 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity/uri').with(:value => nil)
           is_expected.to contain_tempest_config('identity/uri_v3').with(:value => nil)
           is_expected.to contain_tempest_config('identity/username').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/ca_certificates_file').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => nil)
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v2').with(:value => true)
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
           is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
@@ -190,8 +205,11 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/neutron').with(:value => true)
           is_expected.to contain_tempest_config('service_available/nova').with(:value => true)
           is_expected.to contain_tempest_config('service_available/sahara').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/murano').with(:value => false)
           is_expected.to contain_tempest_config('service_available/swift').with(:value => false)
           is_expected.to contain_tempest_config('service_available/trove').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/ironic').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/zaqar').with(:value => false)
           is_expected.to contain_tempest_config('whitebox/db_uri').with(:value => nil)
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
           is_expected.to contain_tempest_config('oslo_concurrency/lock_path').with(:value => '/var/lib/tempest')
@@ -200,8 +218,10 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('DEFAULT/use_stderr').with(:value => true)
           is_expected.to contain_tempest_config('DEFAULT/use_syslog').with(:value => false)
           is_expected.to contain_tempest_config('DEFAULT/log_file').with(:value => nil)
+          is_expected.to contain_tempest_config('DEFAULT/logging_context_format_string').with(:value => nil)
           is_expected.to contain_tempest_config('scenario/img_dir').with(:value => '/var/lib/tempest')
           is_expected.to contain_tempest_config('scenario/img_file').with(:value => 'cirros-0.3.4-x86_64-disk.img')
+          is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => false)
         end
 
         it 'set glance id' do
@@ -229,6 +249,36 @@ describe 'tempest' do
     end
   end
 
+  shared_examples 'tempest with plugins packages' do
+    let :pre_condition do
+      "include ::glance
+       class { 'neutron': rabbit_password => 'passw0rd' }"
+    end
+
+    context 'with when managing tests packages for keystone (required service)' do
+      let :params do
+        { :manage_tests_packages => true }
+      end
+
+      describe "should install keystone tests package" do
+        it { expect { is_expected.to contain_package('python-keystone-tests') } }
+        it { expect { is_expected.to_not contain_package('python-aodh-tests') } }
+      end
+    end
+
+    context 'with when managing tests packages for aodh (optional service)' do
+      let :params do
+        { :manage_tests_packages => true,
+          :aodh_available        => true }
+      end
+
+      describe "should install keystone tests package" do
+        it { expect { is_expected.to contain_package('python-aodh-tests') } }
+      end
+    end
+  end
+
+
   context 'on Debian platforms' do
     let :facts do
       { :osfamily     => 'Debian' }
@@ -264,6 +314,7 @@ describe 'tempest' do
     end
 
     it_behaves_like 'tempest'
+    it_behaves_like 'tempest with plugins packages'
   end
 
   context 'unsupported operating system' do
